@@ -1,7 +1,7 @@
 /*
 ******************************************************************************
 *                                                                            *
-* Copyright (C) 2001-2012, International Business Machines                   *
+* Copyright (C) 2001-2013, International Business Machines                   *
 *                Corporation and others. All Rights Reserved.                *
 *                                                                            *
 ******************************************************************************
@@ -14,8 +14,8 @@
 *   created by: George Rhoten
 */
 
-#ifndef __UCLN_CMN_H__
-#define __UCLN_CMN_H__
+#ifndef __UCLN_IN_H__
+#define __UCLN_IN_H__
 
 #include "unicode/utypes.h"
 #include "ucln.h"
@@ -26,13 +26,17 @@ as the functions are suppose to be called.
 It's usually best to have child dependencies called first. */
 typedef enum ECleanupI18NType {
     UCLN_I18N_START = -1,
+    UCLN_I18N_IDENTIFIER_INFO,
+    UCLN_I18N_SPOOF,
     UCLN_I18N_TRANSLITERATOR,
     UCLN_I18N_REGEX,
     UCLN_I18N_ISLAMIC_CALENDAR,
     UCLN_I18N_CHINESE_CALENDAR,
     UCLN_I18N_HEBREW_CALENDAR,
     UCLN_I18N_ASTRO_CALENDAR,
+    UCLN_I18N_DANGI_CALENDAR,
     UCLN_I18N_CALENDAR,
+    UCLN_I18N_TIMEZONEFORMAT,
     UCLN_I18N_TIMEZONEGENERICNAMES,
     UCLN_I18N_TIMEZONENAMES,
     UCLN_I18N_ZONEMETA,
@@ -48,8 +52,9 @@ typedef enum ECleanupI18NType {
     UCLN_I18N_UCOL_RES,
     UCLN_I18N_UCOL_BLD,
     UCLN_I18N_CSDET,
-    UCLN_I18N_COLL_DATA,
-    UCLN_I18N_INDEX_CHARACTERS,
+    UCLN_I18N_GENDERINFO,
+    UCLN_I18N_CDFINFO,
+    UCLN_I18N_REGION,
     UCLN_I18N_COUNT /* This must be last */
 } ECleanupI18NType;
 
